@@ -41,7 +41,6 @@
 #include <libegg/eggtreemultidnd.h>
 #include <glib/gi18n.h>
 #include <glib-object.h>
-#include <libgnome/gnome-macros.h>
 #include <libnautilus-extension/nautilus-column-provider.h>
 #include <libnautilus-private/nautilus-column-chooser.h>
 #include <libnautilus-private/nautilus-column-utilities.h>
@@ -493,14 +492,7 @@ motion_notify_callback (GtkWidget *widget,
 
 	if (view->details->drag_button != 0) {
 		if (!source_target_list) {
-			const GtkTargetEntry *drag_types;
-			int n_drag_types;
-
-			fm_list_model_get_drag_types (&drag_types,
-						      &n_drag_types);
-
-			source_target_list = gtk_target_list_new (drag_types,
-								  n_drag_types);
+			source_target_list = fm_list_model_get_drag_target_list ();
 		}
 
 		if (gtk_drag_check_threshold (widget,
